# wai-annotations
Python library for converting annotated datasets into various formats.

* [Installation](doc/INSTALL.md)
* [Usage](doc/USAGE.md)
* [Plugin Guide](doc/PLUGIN.md)
* [Glossary](doc/GLOSSARY.md)
